@@ -96,12 +96,14 @@ class SiteBuilder(object):
                  store_backend,
                  site_name=None,
                  site_index_builder=None,
+                 show_how_to_buttons=True,
                  site_section_builders=None,
                  runtime_environment=None
                  ):
         self.site_name = site_name
         self.data_context = data_context
         self.store_backend = store_backend
+        self.show_how_to_buttons = show_how_to_buttons
 
         # set custom_styles_directory if present
         custom_styles_directory = None
@@ -128,6 +130,7 @@ class SiteBuilder(object):
             runtime_environment={
                 "data_context": data_context,
                 "custom_styles_directory": custom_styles_directory,
+                "show_how_to_buttons": self.show_how_to_buttons,
                 "target_store": self.target_store,
                 "site_name": self.site_name
             },
@@ -183,7 +186,8 @@ class SiteBuilder(object):
                 runtime_environment={
                     "data_context": data_context,
                     "target_store": self.target_store,
-                    "custom_styles_directory": custom_styles_directory
+                    "custom_styles_directory": custom_styles_directory,
+                    "show_how_to_buttons": self.show_how_to_buttons,
                 },
                 config_defaults={
                     "name": site_section_name,
@@ -240,6 +244,7 @@ class DefaultSiteSectionBuilder(object):
             target_store,
             source_store_name,
             custom_styles_directory=None,
+            show_how_to_buttons=True,
             run_id_filter=None,
             validation_results_limit=None,
             renderer=None,
@@ -250,6 +255,7 @@ class DefaultSiteSectionBuilder(object):
         self.target_store = target_store
         self.run_id_filter = run_id_filter
         self.validation_results_limit = validation_results_limit
+        self.show_how_to_buttons = show_how_to_buttons
 
         if renderer is None:
             raise exceptions.InvalidConfigError(
@@ -335,7 +341,10 @@ class DefaultSiteSectionBuilder(object):
 
             try:
                 rendered_content = self.renderer_class.render(resource)
-                viewable_content = self.view_class.render(rendered_content)
+                viewable_content = self.view_class.render(
+                    rendered_content,
+                    show_how_to_buttons=self.show_how_to_buttons
+                )
             except Exception as e:
                 exception_message = f'''\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
@@ -376,7 +385,7 @@ class DefaultSiteIndexBuilder(object):
             data_context,
             target_store,
             custom_styles_directory=None,
-            show_cta_footer=True,
+            show_how_to_buttons=True,
             validation_results_limit=None,
             renderer=None,
             view=None,
@@ -386,8 +395,8 @@ class DefaultSiteIndexBuilder(object):
         self.site_name = site_name
         self.data_context = data_context
         self.target_store = target_store
-        self.show_cta_footer = show_cta_footer
         self.validation_results_limit = validation_results_limit
+        self.show_how_to_buttons = show_how_to_buttons
 
         if renderer is None:
             renderer = {
@@ -574,7 +583,7 @@ class DefaultSiteIndexBuilder(object):
         index_links_dict = OrderedDict()
         index_links_dict["site_name"] = self.site_name
 
-        if self.show_cta_footer:
+        if self.show_how_to_buttons:
             index_links_dict["cta_object"] = self.get_calls_to_action()
 
         for expectation_suite_key in expectation_suite_keys:
@@ -630,7 +639,10 @@ class DefaultSiteIndexBuilder(object):
 
         try:
             rendered_content = self.renderer_class.render(index_links_dict)
-            viewable_content = self.view_class.render(rendered_content)
+            viewable_content = self.view_class.render(
+                rendered_content,
+                show_how_to_buttons=self.show_how_to_buttons
+            )
         except Exception as e:
             exception_message = f'''\
 An unexpected Exception occurred during data docs rendering.  Because of this error, certain parts of data docs will \
